% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{stations}
\alias{stations}
\title{Metro and Train Station Locations}
\format{
An sf data frame with POINT geometry (CRS: WGS84 / EPSG:4326)
and the following columns:
\describe{
\item{station_name}{Station name in title case (character).}
\item{line_number}{Line number the station belongs to (integer).}
\item{line_name_pt}{Portuguese color name of the line (character).}
\item{line_name}{English color name of the line (character).}
\item{company_name}{Operating company name (character).}
\item{type}{Either \code{"metro"} (METRO SP) or \code{"train"} (CPTM)
(character).}
\item{status}{Either \code{"current"} (operating) or \code{"future"}
(planned expansion) (character).}
\item{geometry}{Station location (sfc_POINT).}
}
}
\source{
GeoSampa, Prefeitura de Sao Paulo.
\url{https://geosampa.prefeitura.sp.gov.br/}
}
\usage{
stations
}
\description{
Spatial point locations for Sao Paulo metro (METRO SP) and commuter train
(CPTM) stations, including both currently operating stations and planned
future stations.
}
\details{
Requires the \pkg{sf} package to work with spatial features. The distinction
between types isn't always consistent, but we follow GeoSampa's classification.
Broadly speaking, the "metro" runs undergrounds as a subway, and "train" runs
above grounds as a commuter rail (although there are exceptions)
}
\seealso{
\code{\link{lines}} for line route geometries,
\code{\link{station_averages}} for passenger data by station.
}
\keyword{datasets}
